starcluster.commands

Package starcluster :: Package commands |
[hide private]
[frames] | no frames]

# Source Code for Package starcluster.commands

     1  #!/usr/bin/env python
     2  from start import CmdStart
     3  from addnode import CmdAddNode
     4  from removenode import CmdRemoveNode
     5  from stop import CmdStop
     6  from terminate import CmdTerminate
     7  from restart import CmdRestart
     8  from sshmaster import CmdSshMaster
     9  from sshnode import CmdSshNode
    10  from sshinstance import CmdSshInstance
    11  from listclusters import CmdListClusters
    12  from s3image import CmdS3Image
    13  from ebsimage import CmdEbsImage
    14  from downloadimage import CmdDownloadImage
    15  from createvolume import CmdCreateVolume
    16  from resizevolume import CmdResizeVolume
    17  from listkeypairs import CmdListKeyPairs
    18  from listzones import CmdListZones
    19  from listregions import CmdListRegions
    20  from listimages import CmdListImages
    21  from listbuckets import CmdListBuckets
    22  from showimage import CmdShowImage
    23  from showbucket import CmdShowBucket
    24  from removevolume import CmdRemoveVolume
    25  from removeimage import CmdRemoveImage
    26  from listinstances import CmdListInstances
    27  from listspots import CmdListSpots
    28  from showconsole import CmdShowConsole
    29  from listvolumes import CmdListVolumes
    30  from listpublic import CmdListPublic
    31  from runplugin import CmdRunPlugin
    32  from spothistory import CmdSpotHistory
    33  from loadbalance import CmdLoadBalance
    34  from shell import CmdShell
    35  from createkey import CmdCreateKey
    36  from removekey import CmdRemoveKey
    37  from put import CmdPut
    38  from get import CmdGet
    39  from help import CmdHelp
    40
    41  all_cmds = [
    42      CmdStart(),
    43      CmdStop(),
    44      CmdTerminate(),
    45      CmdRestart(),
    46      CmdListClusters(),
    47      CmdSshMaster(),
    48      CmdSshNode(),
    49      CmdPut(),
    50      CmdGet(),
    51      CmdAddNode(),
    52      CmdRemoveNode(),
    53      CmdLoadBalance(),
    54      CmdSshInstance(),
    55      CmdListInstances(),
    56      CmdListSpots(),
    57      CmdListImages(),
    58      CmdListPublic(),
    59      CmdListKeyPairs(),
    60      CmdCreateKey(),
    61      CmdRemoveKey(),
    62      CmdS3Image(),
    63      CmdEbsImage(),
    64      CmdShowImage(),
    65      CmdDownloadImage(),
    66      CmdRemoveImage(),
    67      CmdCreateVolume(),
    68      CmdListVolumes(),
    69      CmdResizeVolume(),
    70      CmdRemoveVolume(),
    71      CmdSpotHistory(),
    72      CmdShowConsole(),
    73      CmdListRegions(),
    74      CmdListZones(),
    75      CmdListBuckets(),
    76      CmdShowBucket(),
    77      CmdRunPlugin(),
    78      CmdShell(),
    79      CmdHelp(),
    80  ]
    81